.. _homogenization-material_opt:

homogenization/material_opt.py
==============================

**Description**


See the :ref:`sec-mat_optim` tutorial for a comprehensive description of this
example.




:download:`source code </../sfepy/examples/homogenization/material_opt.py>`

.. literalinclude:: /../sfepy/examples/homogenization/material_opt.py

